@@ -30,7 +30,7 @@ our @EXPORT = qw(
     x
 );
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0302';
 
 my $self;
 
@@ -165,63 +165,85 @@ Easy, command-line MIDI!
 
 =head2 b
 
+  b(100)
+
 Set BPM
 
 =head2 c
 
+  c(15)
+
 Channel
 
 Default: C<0>
 
 =head2 d
 
+  d(128)
+
 Duration
 
 Default: C<96>
 
 =head2 e
 
+  e(0)
+
 Play at end
 
 Default: C<1>
 
 =head2 n
 
-Add note
+  n(@note_spec)
+
+Add note.  See the L<MIDI::Simple> documentation for what a
+"note_spec" is.
 
 =head2 o
 
+  o(3)
+
 Octave
 
 Default: C<5>
 
 =head2 p
 
+  p($channel, $patch_number)
+
 Patch
 
-Default: C<0> (piano)
+Default: C<0, 0> (channel 0, piano)
 
 =head2 r
 
-Add rest
+  r($note_duration)
+
+Add rest. See the L<MIDI::Simple> documentation for what
+"note_durations" are valid.
 
 =head2 t
 
+  t("$numerator/$denominator")
+
 Time signature
 
 Default: C<none>
 
 =head2 v
 
+  v(127)
+
 Volume
 
 Default: C<64>
 
 =head2 w
 
-Write score to a temporary file.
+  w('filename.mid')
 
-Supply a string argument to set and use a persistent B<filename>.
+Write score to a file.
 
 =head2 x
 
@@ -234,6 +256,8 @@ No-op (with C<MIDI::Simple::noop>)
 
 =head1 SEE ALSO
 
+The F<t/01-methods.t> file in this distribution
+
 L<Exporter>
 
 L<File::Slurper>
